@@ -32,8 +32,11 @@ class DBConnect:
 
     def write_one_docu(self, docu: dict) -> str:
         try:
+            # 添加创建时间和更新时间，日期格式
             if not docu.__contains__('creation_time'):
                 docu['creation_time'] = datetime.today()
+            if not docu.__contains__('update_time'):
+                docu['update_time'] = datetime.today()
             new_data = self.mongo_collection.insert_one(docu)
             return str(new_data.inserted_id)
         except Exception as err:
@@ -50,9 +53,13 @@ class DBConnect:
 
     def update_docu(self, find_docu: dict, modify_docu: dict, many=False) -> dict:
         try:
+            # 将参数id处理成符合mongo格式的_id对象
             find_docu = handle_db_id(find_docu)
             # 排除假删除数据
             find_docu = handle_db_remove(find_docu)
+            # 重置更新时间
+            if not modify_docu.__contains__('update_time'):
+                modify_docu['update_time'] = datetime.today()
             if many:
                 student = self.mongo_collection.update_many(
                     find_docu, modify_docu)
