@@ -65,10 +65,13 @@ def handle_db_id(data_dict: dict) -> dict:
         logging.warning("类型错误，预期 %s ,却得到 %s" % (dict, type(id)))
         abort(Response("类型错误，预期 %s ,却得到 %s" % (dict, type(id)), 400, {}))
     try:
-        if data_dict.__contains__('_id'):
+        if data_dict.__contains__('_id') and isinstance(data_dict['_id'], str):
             data_dict['_id'] = ObjectId(str(data_dict['_id']))
         elif data_dict.__contains__('id'):
-            data_dict['_id'] = ObjectId(str(data_dict['id']))
+            if isinstance(data_dict['id'], str):
+                data_dict['_id'] = ObjectId(str(data_dict['id']))
+            else:
+                data_dict['_id'] = data_dict['id']
             del data_dict['id']
         return data_dict
     except Exception as err:
